/**
 * This class implements a simple cdata generator that produces random
 * almost-readable text according to the grammar specified by the
 * XMark benchmark
 *
 * This code is provided as part of ToXgene - (c) 2001 University of Toronto
 * and IBM Corporation.
 *
 * @author Denilson Barbosa
 * @version 1.0
 */

package util.cdata.xmark;

import toxgene.ToXgene;

import java.io.IOException;
import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.jar.JarFile;

import genes.literals.Cdata;
import java.util.Random;

public class LastNames implements Cdata{
	public static int len = 10000;
	public static String[] data;
	public static boolean loaded = false;

	private static Random pick;
	private static String result;


	/**
	 * Constructor. There are too many constants to be loaded here, so
	 * we cannot declare them explicitly as data = {...}, so we load the
	 * words stored in a file within the toxgene.jar package.
	 */
	public LastNames(){
		init();
	}
	
	/**
	 * Specifies a seed for the random generator so that repeated
	 * executions always produce the same content, if the same seed is
	 * provided.
	 */
	public void setRandomSeed(int seed){
		pick = new Random(seed);
	}
	
	/**
	 * Generates random text that is at most @param length characters
	 * long if @param lenght is different than -1.
	 */
	public String getCdata(int length){
		result = data[pick.nextInt(len)];

		//length == -1 means that the string should not be trimmed
		if (length == -1){
			return result;
		}

		if (result.length() > length)
			return result.substring(0,length);
		else
			return result;
	}
	
	/**
	 * This method does all the work of loading the words into
	 * memory. ToXgene is a static class and tgHome is a static variable
	 * that contains the path where toxgene.jar should be.
	 */
	public static void init(){
		if (loaded)
			return;

		data = new String[len];

		try{
			JarFile jar_file = new JarFile(ToXgene.tgHome+"/toxgene.jar");
			InputStream i_s_r =
				jar_file.getInputStream(jar_file.
																getEntry("util/cdata/xmark/lnames.txt"));
			BufferedReader reader = new BufferedReader(new InputStreamReader(i_s_r));

			String line = null, word = null;
			int index, last, count;
			count = 0;
			do{
				line = reader.readLine();
				if (line == null)
					break;

				last = 0;
				index = line.indexOf(',');
				while (index != -1){
					data[count++] = line.substring(last,index);
					last = index+1;
					index = line.indexOf(',',last);
				}
			}while (true);
		}
		catch (Exception e){
			ToXgene.error("could not initialize Xmark text generator (lnames.txt)");
		}

		loaded = true;
	}
}
